import pytest
from django.urls import reverse
from django.core.files.uploadedfile import SimpleUploadedFile

from aircox.models import Program


@pytest.mark.django_db()
def test_edit_program(user, client, program):
    client.force_login(user)
    response = client.get(reverse("program-detail", kwargs={"slug": program.slug}))
    assert response.status_code == 200
    assert "🖉 ".encode() not in response.content
    user.groups.add(program.editors)
    response = client.get(reverse("program-detail", kwargs={"slug": program.slug}))
    assert "🖉 ".encode() in response.content
    assert b"foobar" not in response.content
    response = client.post(reverse("program-edit", kwargs={"pk": program.pk}), {"content": "foobar"})
    response = client.get(reverse("program-detail", kwargs={"slug": program.slug}))
    assert b"foobar" in response.content


@pytest.mark.django_db()
def test_add_cover(user, client, program, png_content):
    assert program.cover is None
    user.groups.add(program.editors)
    client.force_login(user)
    cover = SimpleUploadedFile("cover1.png", png_content, content_type="image/png")
    r = client.post(
        reverse("program-edit", kwargs={"pk": program.pk}), {"content": "foobar", "new_cover": cover}, follow=True
    )
    assert r.status_code == 200
    p = Program.objects.get(pk=program.pk)
    assert "cover1.png" in p.cover.url
